@@ -89,10 +89,11 @@ class PSF(Effect):
 
                 if image.ndim == 2 and kernel.ndim == 2:
                     new_image = convolve(image - bkg_level, kernel, mode=mode)
-                elif kernel.ndim == 2:
+                elif image.ndim == 3 and kernel.ndim == 2:
                     kernel = kernel[None, :, :]
+                    bkg_level = bkg_level[:, None, None]
                     new_image = convolve(image - bkg_level, kernel, mode=mode)
-                elif kernel.ndim == 3:
+                elif image.ndim == 3 and kernel.ndim == 3:
                     bkg_level = bkg_level[:, None, None]
                     new_image = np.zeros(image.shape)  # assumes mode="same"
                     for iplane in range(image.shape[0]):
@@ -266,23 +267,30 @@ class NonCommonPathAberration(AnalyticalPSF):
 class SeeingPSF(AnalyticalPSF):
     """
     Currently only returns gaussian kernel with a ``fwhm`` [arcsec]
+
+    Parameters
+    ----------
+    fwhm : flaot
+        [arcsec]
+
     """
     def __init__(self, fwhm=1.5, **kwargs):
         super().__init__(**kwargs)
+
         self.meta["fwhm"] = fwhm
         self.meta["z_order"] = [242, 642]
 
-    def fov_grid(self, which="waveset", **kwargs):
-        wavelengths = []
-        if which == "waveset" and \
-                "waverange" in kwargs and \
-                "pixel_scale" in kwargs:
-            waverange = utils.quantify(kwargs["waverange"], u.um)
-            wavelengths = waverange
-            # ..todo: return something useful
-
-        # .. todo: check that this is actually correct
-        return wavelengths
+    # def fov_grid(self, which="waveset", **kwargs):
+    #     wavelengths = []
+    #     if which == "waveset" and \
+    #             "waverange" in kwargs and \
+    #             "pixel_scale" in kwargs:
+    #         waverange = utils.quantify(kwargs["waverange"], u.um)
+    #         wavelengths = waverange
+    #         # ..todo: return something useful
+    #
+    #     # .. todo: check that this is actually correct
+    #     return wavelengths
 
     def get_kernel(self, fov):
         # called by .apply_to() from the base PSF class
@@ -292,7 +300,7 @@ class SeeingPSF(AnalyticalPSF):
         wave = fov.wavelength
 
         # add in the conversion to fwhm from seeing and wavelength here
-        fwhm = self.meta["fwhm"] * u.arcsec / pixel_scale
+        fwhm = utils.from_currsys(self.meta["fwhm"]) * u.arcsec / pixel_scale
 
         sigma = fwhm.value / 2.35
         kernel = Gaussian2DKernel(sigma, mode="center").array
@@ -603,7 +611,7 @@ class FieldConstantPSF(DiscretePSF):
 
                 # compare kernel and fov pixel scales, rescale if needed
                 if "CUNIT1" in hdr:
-                    unit_factor = u.Unit(hdr["CUNIT1"]).to(u.deg)
+                    unit_factor = u.Unit(hdr["CUNIT1"].lower()).to(u.deg)
                 else:
                     unit_factor = 1
 
@@ -627,7 +635,7 @@ class FieldConstantPSF(DiscretePSF):
         # Some data from the fov
         nxfov, nyfov = fov.hdu.header["NAXIS1"], fov.hdu.header["NAXIS2"]
         fov_pixel_scale = fov.hdu.header["CDELT1"]
-        fov_pixel_unit = fov.hdu.header["CUNIT1"]
+        fov_pixel_unit = fov.hdu.header["CUNIT1"].lower()
 
         lam = fov.hdu.header["CDELT3"] * (1 + np.arange(fov.hdu.header["NAXIS3"])
                                           - fov.hdu.header["CRPIX3"]) \
@@ -643,7 +651,7 @@ class FieldConstantPSF(DiscretePSF):
         refwave = hdr[self.meta["wave_key"]]
 
         if "CUNIT1" in hdr:
-            unit_factor = u.Unit(hdr["CUNIT1"]).to(u.Unit(fov_pixel_unit))
+            unit_factor = u.Unit(hdr["CUNIT1"].lower()).to(u.Unit(fov_pixel_unit))
         else:
             unit_factor = 1
         ref_pixel_scale = hdr["CDELT1"] * unit_factor
